import os
import glob
from distutils.core import setup, Extension
import sys
import argparse

parser = argparse.ArgumentParser()
parser.add_argument('--no-pdb2pka', action="store_true")
options, sys.argv[1:] = parser.parse_known_args()

##
## patch main.py -> pdb2pqr.py
##

with open('main.py') as handle:
    contents = handle.read()

contents = contents.replace(
        'def mainCommand(argv):',
        'def mainCommand(argv=sys.argv):')

with open('pdb2pqr.py', 'w') as handle:
    handle.write(contents)

##
## patch src/utilities.py
##

with open('src/utilities.py') as handle:
    contents = handle.read()

contents = contents.replace(
        'sys.path',
        '[os.path.dirname(__file__)]')

with open('src/utilities.py', 'w') as handle:
    handle.write(contents)

##
## patch *.in files
##

for filename in glob.glob('src/*.py.in'):
    with open(filename) as handle:
        contents = handle.read()

    contents = contents.replace('@MAXATOMS@', '10000')
    contents = contents.replace('@INSTALLDIR@', '/')
    contents = contents.replace('@APBS_LOCATION@', os.path.join(os.environ['PREFIX'], 'bin', 'apbs'))

    with open(filename[:-3], 'w') as handle:
        handle.write(contents)

##
## mv dat -> src/dat
##

if os.path.isdir('dat'):
    os.rename('dat', os.path.join('src', 'dat'))

##
## setup
##

kw = dict(
    name="pdb2pqr-minimal",
    packages=[
        "src",
        "extensions",
        "propka30",
        "propka30.Source",
    ],
    py_modules=[
        'pdb2pqr',
    ],
    package_data={
        'src': ['dat/*'],
    },
    ext_modules=[
    ],
)

if not options.no_pdb2pka:
    import numpy

    kw['packages'] += [
        "pdb2pka",
        "pdb2pka.graph_cut",
        "pdb2pka.ligandclean",
        "pdb2pka.substruct",
    ]

    kw['py_modules'] += [
        'pka',
    ]

    kw['package_data']['pdb2pka'] = ['*.DAT']

    kw['ext_modules'] += [
        Extension('pdb2pka._pMC_mult',
            ['pdb2pka/pMC_mult.i', 'pdb2pka/pMC_mult.cpp'],
            swig_opts=['-c++'],
        ),
        Extension('pdb2pka.substruct.Algorithms',
            glob.glob('pdb2pka/substruct/*.cpp'),
            include_dirs=[numpy.get_include()],
        ),
    ]

setup(**kw)
